<?php
/**
 * Plugin Name: myglobalHOST Force Clear Cache
 * Plugin URI:  https://www.myglobalhost.in/
 * Description: Adds a button to the admin toolbar to force clear all cache on your website.
 * Version:     1.0.0
 * Author:      myglobalHOST
 * Author URI:  https://www.myglobalhost.net/
 * License:     GPL2
 */

// Function to add the "Clear Cache" button to the admin toolbar
function add_clear_cache_button() {
    global $wp_admin_bar;

    if ( current_user_can( 'manage_options' ) ) { // Only show to administrators
        $wp_admin_bar->add_menu( array(
            'id'    => 'clear-cache',
            'title' => 'Clear Cache',
            'href'  => wp_nonce_url( admin_url( 'admin-post.php?action=clear_all_cache' ), 'clear_all_cache' ),
            'meta'  => array(
                'class' => 'clear-cache-button', 
            ),
        ) );
    }
}
add_action( 'admin_bar_menu', 'add_clear_cache_button', 999 ); // Add button at the end

// Function to handle the cache clearing action
function clear_all_cache_action() {
    // Verify nonce for security
    if ( ! wp_verify_nonce( $_REQUEST['_wpnonce'], 'clear_all_cache' ) ) {
        wp_die( 'Nonce verification failed.' );
    }

    // Clear all transients (you might want to be more selective here)
    global $wpdb;
    $wpdb->query( "DELETE FROM $wpdb->options WHERE option_name LIKE '_transient_%'" );

    // (Optional) Clear cache from other plugins or your caching mechanism
    // For example, if you're using WP Super Cache:
    // if ( function_exists( 'wp_cache_clear_cache' ) ) {
    //     wp_cache_clear_cache();
    // }

    // Redirect back to the previous page or dashboard
    wp_safe_redirect( wp_get_referer() ? wp_get_referer() : admin_url() );
    exit;
}
add_action( 'admin_post_clear_all_cache', 'clear_all_cache_action' );
